# sklearn-viz

This package provides a collection of interactive (plotly) plots to facilitate scikit-learn model evaluation.

It is very early days, but with time it is hoped the toolset will broaden to provide similar tools to those of the
great [yellowbrick](https://www.scikit-yb.org/en/latest/) package, but with interactive plots built in plotly.


